==> xoops-2.5.0.tbz: www/xoops/htdocs/modules/system/themes/default/language/english/admin.php <==
<?php
// $Id$

define("_OXYGEN_SYSOPTIONS","System Options");
define("_OXYGEN_INSTALLEDMODULES","Installed Modules");

define("_OXYGEN_XOOPSTHEMES","XOOPS Themes");
define("_OXYGEN_XOOPSMODULES","XOOPS Modules");
define("_OXYGEN_INTERESTSITES","Links");
define("_OXYGEN_LOCALSUPPORT","Local Support");
define("_OXYGEN_NEWS","Xoops News");
define("_OXYGEN_WEBSITE","XOOPS");
define("_OXYGEN_SOURCEFORGE","Sourceforge");

define("_OXYGEN_VERSION","Version");
define("_OXYGEN_VERSION_XOOPS","XOOPS Version");
define("_OXYGEN_VERSION_PHP","PHP Version");
define("_OXYGEN_VERSION_MYSQL","mySQL Version");
define("_OXYGEN_Server_API","Server API");
define("_OXYGEN_OS","OS");
define("_OXYGEN_ABOUT","About XOOPS");
define("_OXYGEN_ABOUT_TEXT",'XOOPS is an extensible, OO (Object Oriented), easy to use dynamic web content management system written in PHP. XOOPS is the ideal tool for developing small to large dynamic community websites, intra company portals, corporate portals, weblogs and much more. Read the <a href="http://www.xoops.org/modules/wfchannel/" rel="external">All about XOOPS</a> page for more details.');
define("_OXYGEN_XOOPS_LINKS","XOOPS Links");

define("_OXYGEN_XOOPSPROJECT","XOOPS Project");
define("_OXYGEN_XOOPSCORE","XOOPS Core");
define("_OXYGEN_XOOPSTHEME","XOOPS Themes");
define("_OXYGEN_XOOPSWIKI","XOOPS Wiki");
define("_OXYGEN_XOOPSBOOKS","XOOPS Books");
define("_OXYGEN_NEWMODULE","New Modules");
define("_OXYGEN_XOOPSFAQ","XOOPS FAQ");
define("_OXYGEN_CODESVN","Code SVN");
define("_OXYGEN_REPORTBUG","Report Bug");
define("_OXYGEN_XGIFTSHOP","XOOPS Gift Shop");
define("_OXYGEN_XDONATIONS","Make a Donation");
define("_OXYGEN_XDONATIONS_TEXT",'<h4>We Need Your Help - Make a Donation!</h4>
If you like the XOOPS system, and would like to give something in return, you can make a donation to the XOOPS Foundation! Simply use the PayPal payment system to deposit your donation to the Foundation account.<br />
Your donation will be used to promote and advance the use and development of the XOOPS system. Guaranteed.<br />
The XOOPS Foundation is a registered not-for-profit organisation in the USA, dedicated to promote XOOPS!<br />
All donators will get the Friend of XOOPS rank here on this website. Thanks to the Friends of XOOPS for their donations and continued support<br />
To make a Donation and for more info please visit <a href="http://www.xoops.org/modules/xdonations/" rel="external">here</a>');

define("_OXYGEN_SITEPREF","Preferences");
define("_OXYGEN_GENERAL","General Settings");
define("_OXYGEN_USERSETTINGS","User Info Settings");
define("_OXYGEN_METAFOOTER","Meta Tags and Footer");
define("_OXYGEN_CENSOR","Word Censoring Options");
define("_OXYGEN_SEARCH","Search Options");
define("_OXYGEN_MAILER","Mail Setup");
define("_OXYGEN_AUTHENTICATION","Authentication Options");
define("_OXYGEN_MODULESETTINGS","System Module Settings");

//Add for styles name
define("_OXYGEN_SILVER","Silver");
define("_OXYGEN_DARK","Dark");
define("_OXYGEN_ORANGE","Orange");

//Add 10 des
define("_OXYGEN_XOOPS_LICENSE","XOOPS License");
define("_OXYGEN_KEY","XOOPS Key");
define("_OXYGEN_LICENSE","License");
define("_OXYGEN_RSS","RSS Feed");
define("_OXYGEN_POWERED_BY","Powered by");
define("_OXYGEN_SOURCEFORGE_TEXT","XOOPS Code hosted on SourceForge");
define("_OXYGEN_ADMINISTRATION","XOOPS Administration");
define("_OXYGEN_UPTOP","Up Top");

//Add help 
define("_OXYGEN_HELP_1","How can I make content ?");
define("_OXYGEN_HELP_DESC_1",'To make content you must first install some modules. After that, you can publish your articles. To instal modules use <a href="modules/system/help.php?mid=1&page=modulesadmin">this article </a>and for downloading modules go to : <a href="http://www.xoops.org" rel="external">XOOPS site</a>');
define("_OXYGEN_HELP_2","What is the Block?");
define("_OXYGEN_HELP_DESC_2",'Blocks are discreet sections of content that can be created and configured in the admin interface. Custom blocks can be created and are typically made up of text, graphics and pictures. The content in these blocks may be formatted individually or inherit the site formatting. (<a href="modules/system/help.php?mid=1&page=blocksadmin">more ...</a>)');
define("_OXYGEN_HELP_3","How I can find more help?");
define("_OXYGEN_HELP_DESC_3",'If you need more help and information to using XOOPS you can use <a href="modules/system/help.php">Help pages </a> in system module or use <a href="http://www.xoops.org" rel="external">XOOPS Local support sites </a>');
?>

==> xoops-2.5.5.tbz: www/xoops/htdocs/modules/system/themes/default/language/english/admin.php <==
<?php
// $Id: admin.php 8066 2011-11-06 05:09:33Z beckmi $

define("_OXYGEN_SYSOPTIONS","System Options");
define("_OXYGEN_INSTALLEDMODULES","Installed Modules");

define("_OXYGEN_XOOPSTHEMES","XOOPS Themes");
define("_OXYGEN_XOOPSMODULES","XOOPS Modules");
define("_OXYGEN_INTERESTSITES","Links");
define("_OXYGEN_LOCALSUPPORT","Local Support");
define("_OXYGEN_NEWS","Xoops News");
define("_OXYGEN_WEBSITE","Community Site");
define("_OXYGEN_SOURCEFORGE","Sourceforge");

define("_OXYGEN_VERSION","Version");
define("_OXYGEN_VERSION_XOOPS","XOOPS Version");
define("_OXYGEN_VERSION_PHP","PHP Version");
define("_OXYGEN_VERSION_MYSQL","mySQL Version");
define("_OXYGEN_Server_API","Server API");
define("_OXYGEN_OS","OS");
define("_OXYGEN_ABOUT","About XOOPS");
define("_OXYGEN_ABOUT_TEXT",'Read the <a href="http://www.xoops.org/modules/wfchannel/" rel="external">All about XOOPS</a> page for more details.');
define("_OXYGEN_XOOPS_LINKS","XOOPS Links");

define("_OXYGEN_XOOPSPROJECT","XOOPS Project");
define("_OXYGEN_XOOPSCORE","XOOPS Core");
define("_OXYGEN_XOOPSTHEME","XOOPS Themes");
define("_OXYGEN_XOOPSWIKI","XOOPS Wiki");
define("_OXYGEN_XOOPSBOOKS","XOOPS Books");
define("_OXYGEN_NEWMODULE","New Modules");
define("_OXYGEN_XOOPSFAQ","XOOPS FAQ");
define("_OXYGEN_CODESVN","Code SVN");
define("_OXYGEN_REPORTBUG","Report Bug");

define("_OXYGEN_SITEPREF","Preferences");
define("_OXYGEN_GENERAL","General Settings");
define("_OXYGEN_USERSETTINGS","User Info Settings");
define("_OXYGEN_METAFOOTER","Meta Tags and Footer");
define("_OXYGEN_CENSOR","Word Censoring Options");
define("_OXYGEN_SEARCH","Search Options");
define("_OXYGEN_MAILER","Email Setup");
define("_OXYGEN_AUTHENTICATION","Authentication Options");
define("_OXYGEN_MODULESETTINGS","System Module Settings");

//Add for styles name
define("_OXYGEN_SILVER","Silver");
define("_OXYGEN_DARK","Dark");
define("_OXYGEN_ORANGE","Orange");

//Add 10 des
define("_OXYGEN_XOOPS_LICENSE","XOOPS License");
define("_OXYGEN_RSS","RSS Feed");
define("_OXYGEN_ADMINISTRATION","XOOPS Administration");
define("_OXYGEN_UPTOP","Up Top");

//Add help
define("_OXYGEN_HELP_1","How can I make content ?");
define("_OXYGEN_HELP_DESC_1",'To make content you must first install some module, like the <a href="http://xoops.svn.sourceforge.net/viewvc/xoops/XoopsModules/fmcontent/trunk/?view=tar" rel="external">fmContent</a> or the <a href="https://sourceforge.net/projects/xoops/files/XOOPS%20Module%20Repository/XOOPS2/Content/XOOPS2.5_mod_content_1.4_kerkyra.zip/download" rel="external">Content</a> module. To loarn more about modules <a href="modules/system/help.php?mid=1&page=modulesadmin">click here</a>' );
define("_OXYGEN_HELP_2","What is the Block?");
define("_OXYGEN_HELP_DESC_2",'Blocks can provide additional/specific content from the installed modules. There can be and custom blocks which can contain text, JS Code, HTML formatted text, pictures, etc. The content in these blocks may be formatted individually or can inherit formatting from the Website. (<a href="modules/system/help.php?mid=1&page=blocksadmin">more ...</a>)');
define("_OXYGEN_HELP_3","How I can find more help?");
define("_OXYGEN_HELP_DESC_3",'If you need more help and information to using XOOPS you can use <a href="modules/system/help.php">Help pages </a> in system module or use <a href="http://www.xoops.org" rel="external">XOOPS Local support sites </a>');
?>
